
# simple_rl Examples

These examples demonstrate how to interface cherry with David Abel's [simple_rl](https://github.com/david-abel/simple_rl).

## Requirements

* simple_rl, torch, and cherry installed.

```shell
pip install simple_rl
```

## Examples Descriptions

### Q-Learning

Implements a simple_rl agent that learns differentiable Q-functions using Q-learning.

**Command** `python simple_q_mdp.py`

**Status** Correct, might need further hyper-parameter tuning for Linear and MLP Q-functions.

